@@ -24,7 +24,7 @@ def vaild_decorator(obj=None, obj_serializer=None, partial=False):
             """
             try:
                 if request.method == "GET":
-                    data = request.GET
+                    data = request.GET.dict()
                 else:
                     data = request.data
                 serializer = obj_serializer(data=data, partial=partial)
