@@ -68,8 +68,12 @@ class ESClient(BaseArgsParsing):
                     for range_item in body:
                         if key in range_item.keys():
                             if itme[1] in range_item[key].keys():
-                                range_item[key][itme[1]] = self.build(range_item[key], ".".join(itme[1:]), field, vaule)
-                                return body
+                                range_item[key][itme[1]] = self.build(
+                                    range_item[key], ".".join(itme[1:]), field, vaule
+                                )
+                                break
+                    else:
+                        body.append({key: self.build({}, ".".join(itme[1:]), field, vaule)})
                 else:
                     for item in body:
                         if key in item.keys():
